﻿using MedicalDatabaseContracts;
using MedicalDatabaseContracts.Models;
using MedicalDatabaseContracts.SearchModels;
using MedicalDatabaseContracts.ViewModels;
using Microsoft.Extensions.Logging;

namespace MedicalView.Diagnoses
{
    public partial class FormDiagnose : FormAbstractDetail
    {
        private readonly ILogger<FormDiagnose> _logger;
        private readonly ILogic<Diagnose, DiagnoseViewModel, DiagnoseSearchModel> _diagnoseLogic;
        public FormDiagnose(ILogger<FormDiagnose> logger,
            ILogic<Diagnose, DiagnoseViewModel, DiagnoseSearchModel> diagnoseLogic)
        {
            InitializeComponent();
            _diagnoseLogic = diagnoseLogic;
            _logger = logger;
        }

        private void FormDiagnose_Load(object sender, EventArgs e)
        {
            if (ModelId.HasValue)
            {
                try
                {
                    _logger.LogInformation("Получение диагноза");
                    var view = _diagnoseLogic.ReadElement(ModelId.Value);
                    if (view != null)
                    {
                        textBoxName.Text = view.Name;
                    }
                }
                catch (Exception ex)
                {
                    _logger.LogError(ex, "Ошибка получения диагноза");
                    MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        private void CancelToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Cancel();
        }

        private void ApplyToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(textBoxName.Text))
            {
                MessageBox.Show("Заполните название", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            _logger.LogInformation("Сохранение диагноза");
            try
            {
                var model = new Diagnose
                {
                    Id = ModelId ?? 0,
                    Name = textBoxName.Text,
                };
                var operationResult = ModelId.HasValue ? _diagnoseLogic.Update(model) : _diagnoseLogic.Create(model);
                if (!operationResult)
                {
                    throw new Exception("Ошибка при сохранении. Дополнительная информация в логах.");
                }
                MessageBox.Show("Сохранение прошло успешно", "Сообщение", MessageBoxButtons.OK, MessageBoxIcon.Information);
                DialogResult = DialogResult.OK;
                Close();
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка сохранения диагноза");
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}
